@@ -13,20 +13,30 @@
 #     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 from __future__ import print_function
+
 import subprocess
-import re
 
 
 def register_param(parser):
     group = parser.register_group("slurmCoat")
-    group.add_argument("--module", type=str, nargs="*",
-                       help="list of modules to load before launching the job")
-    group.add_argument("--current_cwd", action='store_true',
-                       help="Asks to run the job where the script is launched",
-                       default=False)
     group.add_argument(
-        "--slurm_options", type=str, nargs='*',
-        help="Additional option to pass to SLURM (to be called several times).")
+        "--module",
+        type=str,
+        nargs="*",
+        help="list of modules to load before launching the job",
+    )
+    group.add_argument(
+        "--current_cwd",
+        action="store_true",
+        help="Asks to run the job where the script is launched",
+        default=False,
+    )
+    group.add_argument(
+        "--slurm_options",
+        type=str,
+        nargs="*",
+        help="Additional option to pass to SLURM (to be called several times).",
+    )
 
 
 def launch(run, params):
@@ -36,6 +46,7 @@ def launch(run, params):
 
     slurm_head_name = f"#SBATCH --job-name={run.id}_{run['run_name']}\n"
     head += slurm_head_name
+    head += "#SBATCH --signal=B:TERM@60\n"
 
     run["state"] = "SLURM submit"
 
@@ -65,13 +76,16 @@ def launch(run, params):
 
     run.update()
 
-    head += """
+    head += (
+        """
 
 export BLACKDYNAMITE_HOST=__BLACKDYNAMITE__dbhost__
 export BLACKDYNAMITE_SCHEMA=__BLACKDYNAMITE__study__
 export BLACKDYNAMITE_STUDY=__BLACKDYNAMITE__study__
 export BLACKDYNAMITE_RUN_ID=__BLACKDYNAMITE__run_id__
-export BLACKDYNAMITE_USER=""" + params["user"] + """
+export BLACKDYNAMITE_USER="""
+        + params["user"]
+        + """
 
 on_kill()
 {
@@ -92,10 +106,11 @@ trap on_stop SIGTERM
 trap on_kill SIGUSR2
 trap on_kill SIGKILL
 """
+    )
 
     _exec["file"] = run.replaceBlackDynamiteVariables(head) + _exec["file"]
 
-    f = open(_exec["filename"], 'w')
+    f = open(_exec["filename"], "w")
     f.write(_exec["file"])
     f.close()
     # os.chmod(_exec["filename"], stat.S_IRWXU)
