@@ -20,6 +20,7 @@ from functools import reduce
 
 ################################################################
 import BTrees
+
 ################################################################
 from deprecated import deprecated
 
@@ -274,6 +275,7 @@ class RunZEO(zeoobject.ZEOObject):
                 logger.warning(f"run {self.id} has no quantity: {q}")
                 return None
         import pandas as pd
+
         array = reduce(
             lambda left, right: pd.merge(left, right, on="step[int]", how="outer"), res
         )
@@ -290,6 +292,7 @@ class RunZEO(zeoobject.ZEOObject):
     @zeoobject._transaction
     def pushQuantity(self, vals, steps, name, description=None):
         import numpy as np
+
         quantities = self.base.quantities
         if name not in quantities and description is not None:
             quantities[name] = description
@@ -336,6 +339,7 @@ class RunZEO(zeoobject.ZEOObject):
         fname = self.getQuantityBlob(name)
         ext = os.path.splitext(fname)[1]
         import pandas as pd
+
         if ext == ".csv":
             _f = pd.read_csv(fname)
         else:
@@ -463,4 +467,9 @@ def getRunFromScript():
         mybase = base.Base(**params)
     myrun = mybase.runs[params["run_id"]]
     myjob = mybase.jobs[myrun.job_id]
+
+    while myrun.state == "CREATED" or myrun.state == "TOBELAUNCHED":
+        import time
+
+        time.sleep(0.1)
     return myrun, myjob
