@@ -19,6 +19,7 @@
 import argparse
 import subprocess
 import sys
+
 import argcomplete
 import lazy_loader as lazy
 
@@ -39,6 +40,7 @@ fix_zeodb = lazy_load("fix_zeodb")
 getJobInfo = lazy_load("getJobInfo")
 getRunInfo = lazy_load("getRunInfo")
 launch_daemon = lazy_load("launch_daemon")
+reset = lazy_load("reset")
 launchRuns = lazy_load("launchRuns")
 open_zeodb = lazy_load("open_zeodb")
 plotRuns = lazy_load("plotRuns")
@@ -92,6 +94,8 @@ class BDCompleter(argcomplete.CompletionFinder):
             bd_zeo_server.main([])
         elif parsed_args.target == "launch_daemon":
             launch_daemon.main([])
+        elif parsed_args.target == "reset":
+            reset.main([])
         elif parsed_args.target == "clone":
             clone.main([])
         elif parsed_args.target == "pull":
@@ -143,6 +147,12 @@ Every command may apply to db (database), jobs or runs.
         add_help=False,
     )
 
+    target_parsers.add_parser(
+        "reset",
+        help="command specific to reset completely a BD study",
+        add_help=False,
+    )
+
     parser_zeodb = target_parsers.add_parser(
         "zeodb", help="command to the specific to the zeo db"
     )
@@ -236,6 +246,8 @@ def execute(pre_args, unknown):
             getJobInfo.main(unknown)
     elif pre_args.target == "launch_daemon":
         launch_daemon.main(unknown)
+    elif pre_args.target == "reset":
+        reset.main(unknown)
     elif pre_args.target == "runs":
         if pre_args.command == "create":
             createRuns.main(unknown)
